act.plotting.WindRoseDisplay
============================

.. currentmodule:: act.plotting

.. autoclass:: WindRoseDisplay

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~WindRoseDisplay.__init__
      ~WindRoseDisplay.add_colorbar
      ~WindRoseDisplay.add_subplots
      ~WindRoseDisplay.assign_to_figure_axis
      ~WindRoseDisplay.plot
      ~WindRoseDisplay.put_display_in_subplot
      ~WindRoseDisplay.set_rrng
      ~WindRoseDisplay.set_thetarng
   
   

   
   
   